from django import forms
from django_grapesjs.forms import GrapesJsWidget
from django_grapesjs.settings import BASE, GRAPESJS_DEFAULT_HTML, REDACTOR_CONFIG

__all__ = (
    'GrapesJsField',
)


class GrapesJsField(forms.CharField):
    '''
    Form field with support grapesjs.
    '''

    widget = GrapesJsWidget

    def __init__(self, max_length=None, min_length=None, strip=True, empty_value='',
                 default_html=GRAPESJS_DEFAULT_HTML, html_name_init_conf=REDACTOR_CONFIG[BASE],
                 *args, **kwargs):
        super().__init__(max_length=None, min_length=None, strip=True, empty_value='', *args, **kwargs)

        self.widget.default_html = default_html
        self.widget.html_name_init_conf = html_name_init_conf




from django.db import models
from django_grapesjs.forms.widgets import GrapesJsWidget
from django_grapesjs.forms.fields import GrapesJsField
from django_grapesjs.settings import BASE, GRAPESJS_DEFAULT_HTML, REDACTOR_CONFIG

__all__ = (
    'GrapesJsHtmlField',
)


class GrapesJsHtmlField(models.TextField):
    """
    Model field with support grapesjs.

    """
    def __init__(self, verbose_name=None, name=None, auto_now=False,
                 auto_now_add=False, default_html=GRAPESJS_DEFAULT_HTML,
                 redactor_config=BASE, **kwargs):
        self.default_html = default_html
        self.html_name_init_conf = REDACTOR_CONFIG[redactor_config]

        super().__init__(verbose_name, name, **kwargs)

    def formfield(self, **kwargs):
        kwargs['form_class'] = GrapesJsField
        kwargs['widget'] = GrapesJsWidget
        kwargs['default_html'] = self.default_html
        kwargs['html_name_init_conf'] = self.html_name_init_conf

        return super().formfield(**kwargs)




from django.conf import settings


# path to the html file of the form field. Enter your value for the override
GRAPESJS_TEMPLATE = getattr(settings, 'GRAPESJS_TEMPLATE', 'django_grapesjs/textarea.html')

# True if you want to save html and css
GRAPESJS_SAVE_CSS = int(getattr(settings, 'GRAPESJS_SAVE_CSS', False))

# use the value of the field from the db - True, or use the global save editor
GRAPESJS_DEFAULT_MODELS_DATA = int(getattr(settings, 'GRAPESJS_DEFAULT_MODELS_DATA', True))

# redefine the path to the html file, the markup from this file will be used by default
GRAPESJS_DEFAULT_HTML = getattr(settings, 'GRAPESJS_DEFAULT_HTML', 'django_grapesjs/default.html')

MIN = 'min'
BASE = 'base'

# Use this dictionary to override or add editor configurations
REDACTOR_CONFIG = {
    MIN: 'django_grapesjs/redactor_config/min.html',
    BASE: 'django_grapesjs/redactor_config/base.html',
    **getattr(settings, 'REDACTOR_CONFIG', {})
}

STATIC_URL = getattr(settings, 'STATIC_URL', '/static/')




from django_grapesjs.settings import GRAPESJS_SAVE_CSS, GRAPESJS_DEFAULT_MODELS_DATA
from django import template


register = template.Library()


@register.simple_tag
def get_save_css_value():
    return GRAPESJS_SAVE_CSS


@register.simple_tag
def get_default_models_data():
    return GRAPESJS_DEFAULT_MODELS_DATA





from django_grapesjs.settings import GRAPESJS_TEMPLATE, STATIC_URL
from django.template.loader import render_to_string
from django import forms

__all__ = (
    'GrapesJsWidget',
)


class GrapesJsWidget(forms.Textarea):
    '''
    Textarea form widget with support grapesjs.
    This is widget base config grapesjs.

    '''
    template_name = GRAPESJS_TEMPLATE

    class Media:
        css = {
            'all': (
                STATIC_URL + 'css/django_grapesjs/grapes.min.css',
                STATIC_URL + 'css/django_grapesjs/grapesjs-preset-newsletter.css',
                STATIC_URL + 'css/django_grapesjs/grapesjs-preset-webpage.min.css',
                STATIC_URL + 'css/django_grapesjs/grapesjs-plugin-filestack.css',
            )
        }
        js = [
            '//static.filestackapi.com/v3/filestack.js',
            '//feather.aviary.com/imaging/v3/editor.js',
            STATIC_URL + 'js/django_grapesjs/grapes.js',
            STATIC_URL + 'js/django_grapesjs/grapesjs-aviary.min.js',
            STATIC_URL + 'js/django_grapesjs/grapesjs-preset-newsletter.min.js',
            STATIC_URL + 'js/django_grapesjs/grapesjs-preset-webpage.min.js',
            STATIC_URL + 'js/django_grapesjs/grapesjs-lory-slider.min.js',
            STATIC_URL + 'js/django_grapesjs/grapesjs-tabs.min.js',
            STATIC_URL + 'js/django_grapesjs/grapesjs-plugin-filestack.min.js',
        ]

    def get_formated_value_id(self, value_id):
        return value_id.replace('-', '_')

    def get_context(self, name, value, attrs):
        context = super().get_context(name, value, attrs)

        context['widget']['attrs']['id'] = self.get_formated_value_id(context['widget']['attrs']['id'])
        context['widget'].update({'get_render_html_value': self.get_render_html_value(self.default_html)})
        context['widget'].update({'html_name_init_conf': self.html_name_init_conf})

        return context

    def get_render_html_value(self, default_html):
        def _get_render_html_value():
            return render_to_string(default_html)

        return _get_render_html_value




import os
from distutils.core import setup
from setuptools import find_packages
from django_grapesjs import __version__


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


setup(
    name = 'django_grapesjs',
    packages = find_packages(exclude=('example*',)),
    include_package_data = True,
    version = __version__,
    description = 'A small library for integrating the page builder "grapesjs" into django admin',
    author = 'Mark Burkut',
    author_email = 'burkut888mark@gmail.com',
    url = 'https://github.com/gulliverbms/django_grapesjs',
    long_description = read('README.rst'),
    long_description_content_type = 'text/x-rst',
    keywords = ['page builder'],
    classifiers = [
        "Framework :: Django :: 1.11",
        "Framework :: Django :: 2.0",
        "Natural Language :: English",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.2",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Environment :: Web Environment",
    ],
    license='MIT',
    install_requires=read('requirements.txt'),
)
